@@ -2,8 +2,8 @@
 /* Generated data (by glib-mkenums) */
 
 #include "e-mail-engine-enumtypes.h"
-/* enumerations from "/usr/src/ports/evolution/evolution-3.18.5.2-1.x86_64/src/evolution-3.18.5.2/libemail-engine/e-mail-engine-enums.h" */
-#include "/usr/src/ports/evolution/evolution-3.18.5.2-1.x86_64/src/evolution-3.18.5.2/libemail-engine/e-mail-engine-enums.h"
+/* enumerations from "/usr/src/ports/evolution/evolution-3.20.5-1.i686/src/evolution-3.20.5/libemail-engine/e-mail-engine-enums.h" */
+#include "/usr/src/ports/evolution/evolution-3.20.5-1.i686/src/evolution-3.20.5/libemail-engine/e-mail-engine-enums.h"
 
 GType
 e_mail_local_folder_get_type (void)
