@@ -2,8 +2,8 @@
 /* Generated data (by glib-mkenums) */
 
 #include "e-shell-enumtypes.h"
-/* enumerations from "/usr/src/ports/evolution/evolution-3.18.5.2-1.x86_64/src/evolution-3.18.5.2/shell/e-shell.h" */
-#include "/usr/src/ports/evolution/evolution-3.18.5.2-1.x86_64/src/evolution-3.18.5.2/shell/e-shell.h"
+/* enumerations from "/usr/src/ports/evolution/evolution-3.20.5-1.x86_64/src/evolution-3.20.5/shell/e-shell.h" */
+#include "/usr/src/ports/evolution/evolution-3.20.5-1.x86_64/src/evolution-3.20.5/shell/e-shell.h"
 
 GType
 e_shell_quit_reason_get_type (void)
